Derive deterministic KWF calendar groups
Source:R/elcf4r_calendar_groups.R
elcf4r_calendar_groups.RdBuild the deterministic day groups used by the residential KWF workflow:
weekdays, pre_holiday, and holiday.
R/elcf4r_calendar_groups.R
elcf4r_calendar_groups.RdBuild the deterministic day groups used by the residential KWF workflow:
weekdays, pre_holiday, and holiday.