Predict from an elcf4r_model
Usage
# S3 method for class 'elcf4r_model'
predict(object, newdata = NULL, ...)Arguments
- object
An
elcf4r_modelcreated by one of the package fit functions.- newdata
Optional new data for methods that need it. For
gamandmars, this should be a long-format data frame with the same predictor columns used for fitting. Forlstm,newdatamay be a matrix or data frame of recent daily segments, or a list with elementssegmentsand optionalcovariates.- ...
Unused, present for method compatibility.